@@ -52,6 +52,9 @@ pub struct EncConfig {
 pub fn encode_rgba(buffer: Img<&[RGBA8]>, config: &EncConfig) -> Result<(Vec<u8>, usize, usize), Box<dyn std::error::Error + Send + Sync>> {
     let width = buffer.width();
     let height = buffer.height();
+    if buffer.buf().len() < width * height {
+        return Err("Too few pixels".into());
+    }
     let mut y_plane = Vec::with_capacity(width*height);
     let mut u_plane = Vec::with_capacity(width*height);
     let mut v_plane = Vec::with_capacity(width*height);
@@ -59,11 +62,11 @@ pub fn encode_rgba(buffer: Img<&[RGBA8]>, config: &EncConfig) -> Result<(Vec<u8>
     for px in buffer.pixels() {
         let (y,u,v) = match config.color_space {
             ColorSpace::YCbCr => {
-                let y  = (0.2126 * px.r as f32 + 0.7152 * px.g as f32 + 0.0722 * px.b as f32).round();
+                let y  = 0.2126 * px.r as f32 + 0.7152 * px.g as f32 + 0.0722 * px.b as f32;
                 let cb = (px.b as f32 - y) * (0.5/(1.-0.0722));
                 let cr = (px.r as f32 - y) * (0.5/(1.-0.2126));
 
-                (y as u8, (cb + 128.).round() as u8, (cr + 128.).round() as u8)
+                (y.round() as u8, (cb + 128.).round() as u8, (cr + 128.).round() as u8)
             },
             ColorSpace::RGB => {
                 (px.g, px.b, px.r)
@@ -100,17 +103,20 @@ pub fn encode_rgba(buffer: Img<&[RGBA8]>, config: &EncConfig) -> Result<(Vec<u8>
 pub fn encode_rgb(buffer: Img<&[RGB8]>, config: &EncConfig) -> Result<(Vec<u8>, usize), Box<dyn std::error::Error + Send + Sync>> {
     let width = buffer.width();
     let height = buffer.height();
+    if buffer.buf().len() < width * height {
+        return Err("Too few pixels".into());
+    }
     let mut y_plane = Vec::with_capacity(width*height);
     let mut u_plane = Vec::with_capacity(width*height);
     let mut v_plane = Vec::with_capacity(width*height);
     for px in buffer.pixels() {
         let (y,u,v) = match config.color_space {
             ColorSpace::YCbCr => {
-                let y  = (0.2126 * px.r as f32 + 0.7152 * px.g as f32 + 0.0722 * px.b as f32).round();
+                let y  = 0.2126 * px.r as f32 + 0.7152 * px.g as f32 + 0.0722 * px.b as f32;
                 let cb = (px.b as f32 - y) * (0.5/(1.-0.0722));
                 let cr = (px.r as f32 - y) * (0.5/(1.-0.2126));
 
-                (y as u8, (cb + 128.).round() as u8, (cr + 128.).round() as u8)
+                (y.round() as u8, (cb + 128.).round() as u8, (cr + 128.).round() as u8)
             },
             ColorSpace::RGB => {
                 (px.g, px.b, px.r)
@@ -133,6 +139,10 @@ pub fn encode_rgb(buffer: Img<&[RGB8]>, config: &EncConfig) -> Result<(Vec<u8>,
 ///
 /// returns AVIF file, size of color metadata, size of alpha metadata overhead
 pub fn encode_raw_planes(width: usize, height: usize, y_plane: &[u8], u_plane: &[u8], v_plane: &[u8], a_plane: Option<&[u8]>, color_pixel_range: PixelRange, config: &EncConfig) -> Result<(Vec<u8>, usize, usize), Box<dyn std::error::Error + Send + Sync>> {
+    if y_plane.len() < width * height {
+        return Err("Too few pixels".into());
+    }
+
     // quality setting
     let quantizer = quality_to_quantizer(config.quality);
     let alpha_quantizer = quality_to_quantizer(config.alpha_quality);
@@ -340,11 +350,7 @@ fn encode_to_av1(p: &Av1EncodeConfig<'_>) -> Result<Vec<u8>, Box<dyn std::error:
         sample_aspect_ratio: Rational::new(1, 1),
         bit_depth,
         chroma_sampling: p.chroma_sampling,
-        chroma_sample_position: if p.chroma_sampling == ChromaSampling::Cs400 {
-            ChromaSamplePosition::Unknown
-        } else {
-            ChromaSamplePosition::Colocated
-        },
+        chroma_sample_position: ChromaSamplePosition::Unknown,
         pixel_range: p.pixel_range,
         color_description: p.color_description,
         mastering_display: None,
